@@ -9,13 +9,13 @@ from .shaderprogram import ShaderProgram
 
 
 class BlockProgram(ShaderProgram):
-    def __init__(self, viewer):
-        super().__init__(viewer)
+    def __init__(self):
+        super().__init__()
         self.base_name = 'Block'
 
     def initialize(self) -> None:
         super().initialize()
-        self.add_uniform_loc('block_size')
+        self.add_uniform_handler('block_size')
 
     def setup_shaders(self) -> None:
         # Placeholders to avoid early garbage collection
