@@ -9,20 +9,16 @@ from .shaderprogram import ShaderProgram
 
 
 class PointProgram(ShaderProgram):
-    def __init__(self, viewer):
-        super().__init__(viewer)
+    def __init__(self):
+        super().__init__()
         self.base_name = 'Point'
 
     def initialize(self) -> None:
         super().initialize()
-        self.add_uniform_loc('viewport')
-        self.add_uniform_loc('marker')
+        self.add_uniform_handler('viewport')
+        self.add_uniform_handler('marker')
 
     def inner_draw(self, drawables: list) -> None:
         for drawable in drawables:
-            # We need DPI awareness for the size of the impostors
-            viewport = [float(self.viewer.devicePixelRatio() * self.viewer.width()),
-                        float(self.viewer.devicePixelRatio() * self.viewer.height())]
-            self.update_uniform('viewport', *viewport)
             self.update_uniform('marker', drawable.element.marker_num)
             drawable.draw()
